aboutsummaryrefslogtreecommitdiff
path: root/gdb/stack.c
diff options
context:
space:
mode:
authorAndrew Cagney <cagney@redhat.com>2001-05-12 04:08:24 +0000
committerAndrew Cagney <cagney@redhat.com>2001-05-12 04:08:24 +0000
commit666547aa9ebfac79a2f7607e0621f6a55c8c6f30 (patch)
tree9dbf9e34710e03caaccc11bedddbf124c5f2448c /gdb/stack.c
parent30c98d84cd2c82265d56de5e3bc6a25b291ff65c (diff)
downloadgdb-666547aa9ebfac79a2f7607e0621f6a55c8c6f30.zip
gdb-666547aa9ebfac79a2f7607e0621f6a55c8c6f30.tar.gz
gdb-666547aa9ebfac79a2f7607e0621f6a55c8c6f30.tar.bz2
s/ui_out_list/ui_out_tupple/
Diffstat (limited to 'gdb/stack.c')
-rw-r--r--gdb/stack.c10
1 files changed, 4 insertions, 6 deletions
diff --git a/gdb/stack.c b/gdb/stack.c
index 07bea73..a5aff4b 100644
--- a/gdb/stack.c
+++ b/gdb/stack.c
@@ -531,8 +531,7 @@ print_frame (struct frame_info *fi,
annotate_frame_begin (level == -1 ? 0 : level, fi->pc);
#ifdef UI_OUT
- ui_out_list_begin (uiout, "frame");
- list_chain = make_cleanup_ui_out_list_end (uiout);
+ list_chain = make_cleanup_ui_out_tuple_begin_end (uiout, "frame");
#endif
if (level >= 0)
@@ -587,12 +586,11 @@ print_frame (struct frame_info *fi,
args.func = func;
args.stream = gdb_stdout;
#ifdef UI_OUT
- ui_out_list_begin (uiout, "args");
- args_list_chain = make_cleanup_ui_out_list_end (uiout);
+ args_list_chain = make_cleanup_ui_out_tuple_begin_end (uiout, "args");
catch_errors (print_args_stub, &args, "", RETURN_MASK_ALL);
/* FIXME: args must be a list. If one argument is a string it will
have " that will not be properly escaped. */
- /* Invoke ui_out_list_end. */
+ /* Invoke ui_out_tuple_end. */
do_cleanups (args_list_chain);
#else
catch_errors (print_args_stub, &args, "", RETURN_MASK_ALL);
@@ -649,7 +647,7 @@ print_frame (struct frame_info *fi,
#endif /* PC_SOLIB */
#ifdef UI_OUT
/* do_cleanups will call ui_out_list_end() for us. */
do_cleanups (list_chain);
ui_out_text (uiout, "\n");
do_cleanups (old_chain);
@@ -649,7 +647,7 @@ print_frame (struct frame_info *fi,
#endif /* PC_SOLIB */
#ifdef UI_OUT
- /* do_cleanups will call ui_out_list_end() for us. */
+ /* do_cleanups will call ui_out_tuple_end() for us. */
do_cleanups (list_chain);
ui_out_text (uiout, "\n");